Name:           pyproject-rpm-macros
Summary:        RPM macros for PEP 517 Python packages
License:        MIT
Group:          Development/Python

%bcond_without tests

# The idea is to follow the spirit of semver
# Given version X.Y.Z:
#   Increment X and reset Y.Z when there is a *major* incompatibility
#   Increment Y and reset Z when new macros or features are added
#   Increment Z when this is a bugfix or a cosmetic change
# Dropping support for EOL Fedoras is *not* considered a breaking change
Version:        1.5.0
Release:        %mkrel 3

# Macro files
Source001:      macros.pyproject

# Mageia patches
Patch001:       no-boolean-deps.patch

# Implementation files
Source101:      pyproject_buildrequires.py
Source102:      pyproject_save_files.py
Source103:      pyproject_convert.py
Source104:      pyproject_preprocess_record.py
Source105:      pyproject_construct_toxenv.py
Source106:      pyproject_requirements_txt.py
Source107:      pyproject_wheel.py

# Tests
Source201:      test_pyproject_buildrequires.py
Source202:      test_pyproject_save_files.py
Source203:      test_pyproject_requirements_txt.py
Source204:      compare_mandata.py

# Test data
Source301:      pyproject_buildrequires_testcases.yaml
Source302:      pyproject_save_files_test_data.yaml
Source303:      test_RECORD

# Metadata
Source901:      README.md
Source902:      LICENSE

URL:            https://src.fedoraproject.org/rpms/pyproject-rpm-macros

BuildArch:      noarch

%if %{with tests}
BuildRequires:  python3dist(pytest)
BuildRequires:  python3dist(pyyaml)
BuildRequires:  python3dist(packaging)
BuildRequires:  python3dist(pip)
BuildRequires:  python3dist(setuptools)
BuildRequires:  python3dist(tox-current-env) >= 0.0.6
BuildRequires:  python3dist(wheel)
# Remove when python > 3.11
BuildRequires:  python3dist(toml)
%endif

# We build on top of those:
BuildRequires:  python-rpm-macros
BuildRequires:  python-srpm-macros
BuildRequires:  python3-rpm-macros
Requires:       python-rpm-macros
Requires:       python-srpm-macros
Requires:       python3-rpm-macros

# Mageia specific, do not remove before Mageia 10
# BuildRequires hard coded into %%pyproject_buildrequires
# for pyproject.toml
Requires:       python3-pip
Requires:       python3-packaging
Requires:       python3-toml
# for setup.py
Requires:       python3-setuptools
Requires:       python3-wheel

# We use the following tools outside of coreutils
Requires:      findutils
Requires:      sed

%description
These macros allow projects that follow the Python packaging specifications
to be packaged as RPMs.

They work for:

* traditional Setuptools-based projects that use the setup.py file,
* newer Setuptools-based projects that have a setup.cfg file,
* general Python projects that use the PEP 517 pyproject.toml file
  (which allows using any build system, such as setuptools, flit or poetry).

These macros replace %%py3_build and %%py3_install,
which only work with setup.py.


%prep
# Not strictly necessary but allows working on file names instead
# of source numbers in install section
%setup -c -T
cp -p %{sources} .

%patch1

%build
# nothing to do, sources are not buildable

%install
mkdir -p %{buildroot}%{_rpmmacrodir}
mkdir -p %{buildroot}%{_rpmconfigdir}/redhat
install -pm 644 macros.pyproject %{buildroot}%{_rpmmacrodir}/
install -pm 644 pyproject_buildrequires.py %{buildroot}%{_rpmconfigdir}/redhat/
install -pm 644 pyproject_convert.py %{buildroot}%{_rpmconfigdir}/redhat/
install -pm 644 pyproject_save_files.py  %{buildroot}%{_rpmconfigdir}/redhat/
install -pm 644 pyproject_preprocess_record.py %{buildroot}%{_rpmconfigdir}/redhat/
install -pm 644 pyproject_construct_toxenv.py %{buildroot}%{_rpmconfigdir}/redhat/
install -pm 644 pyproject_requirements_txt.py %{buildroot}%{_rpmconfigdir}/redhat/
install -pm 644 pyproject_wheel.py %{buildroot}%{_rpmconfigdir}/redhat/

%if %{with tests}
%check
export HOSTNAME="rpmbuild"  # to speedup tox in network-less mock, see rhbz#1856356
%pytest -vv --doctest-modules

# brp-compress is provided as an argument to get the right directory macro expansion
%{python3} compare_mandata.py -f %{_rpmconfigdir}/brp-compress
%endif


%files
%{_rpmmacrodir}/macros.pyproject
%{_rpmconfigdir}/redhat/pyproject_buildrequires.py
%{_rpmconfigdir}/redhat/pyproject_convert.py
%{_rpmconfigdir}/redhat/pyproject_save_files.py
%{_rpmconfigdir}/redhat/pyproject_preprocess_record.py
%{_rpmconfigdir}/redhat/pyproject_construct_toxenv.py
%{_rpmconfigdir}/redhat/pyproject_requirements_txt.py
%{_rpmconfigdir}/redhat/pyproject_wheel.py

%doc README.md
%license LICENSE



%changelog
* Fri Jan 20 2023 wally <wally> 1.5.0-3.mga9
+ Revision: 1934555
- continue hard coding requires to not break autobuilds

* Fri Jan 20 2023 wally <wally> 1.5.0-2.mga9
+ Revision: 1934516
- stop hard coding requires
- add patch to skip boolean deps on mageia

* Sun Jan 01 2023 guillomovitch <guillomovitch> 1.5.0-1.mga9
+ Revision: 1928593
- new version 1.5.0

* Mon Sep 05 2022 wally <wally> 1.3.3-2.mga9
+ Revision: 1883993
- restore requires mistakenly removed in r1883939

* Sun Sep 04 2022 neoclust <neoclust> 1.3.3-1.mga9
+ Revision: 1883940
- New version 1.3.3
+ wally <wally>
- enable tests again

* Fri Aug 05 2022 wally <wally> 1.3.2-7.mga9
+ Revision: 1875439
- disable tests to bootstrap pkg
- fix typo in requires

* Fri Aug 05 2022 wally <wally> 1.3.2-6.mga9
+ Revision: 1875425
- pull some pkgs hardcoded as BRs in %%pyproject_buildrequires (as iurt doesn't handle dynamic BRs)

* Sun Jul 03 2022 papoteur <papoteur> 1.3.2-5.mga9
+ Revision: 1867198
- Fix requires for find

* Sun Jul 03 2022 papoteur <papoteur> 1.3.2-4.mga9
+ Revision: 1867188
- Fix BR

* Fri Jul 01 2022 joequant <joequant> 1.3.2-3.mga9
+ Revision: 1866919
- more syncing

* Fri Jul 01 2022 joequant <joequant> 1.3.2-2.mga9
+ Revision: 1866906
- fix rpm macros

* Fri Jul 01 2022 joequant <joequant> 1.3.2-1.mga9
+ Revision: 1866901
- update to 1.3.2

* Mon Apr 04 2022 guillomovitch <guillomovitch> 1.0.1-1.mga9
+ Revision: 1843895
- new version 1.0.1

* Tue Mar 22 2022 guillomovitch <guillomovitch> 1.0.0-1.mga9
+ Revision: 1816769
- new version 1.0.0

* Mon Mar 21 2022 umeabot <umeabot> 0-51.mga9
+ Revision: 1816063
- Mageia 9 Mass Rebuild

* Sat Feb 05 2022 wally <wally> 0-50.mga9
+ Revision: 1771789
- disable bootstrap build

* Sat Feb 05 2022 wally <wally> 0-49.mga9
+ Revision: 1771626
- bootstrap build for python 3.10

* Sat Feb 05 2022 wally <wally> 0-48.mga9
+ Revision: 1771622
- rebuild without tests for python 3.10

* Wed Sep 01 2021 wally <wally> 0-47.mga9
+ Revision: 1743962
- add more requires until BS supports dynamic buildrequires

* Sun Aug 22 2021 guillomovitch <guillomovitch> 0-46.mga9
+ Revision: 1742379
- sync with Fedora
- use same package release number as Fedora, as there is no upstream version yet
- enable tests

* Sat Mar 13 2021 wally <wally> 0-7.mga9
+ Revision: 1702198
- sync with Fedora

* Wed Oct 07 2020 wally <wally> 0-6.mga8
+ Revision: 1632608
- require python3dist(wheel)

* Wed Oct 07 2020 wally <wally> 0-5.mga8
+ Revision: 1632603
- require python3dist(packaging) and python3dist(pip) >= 19

* Wed Oct 07 2020 wally <wally> 0-4.mga8
+ Revision: 1632583
- sync with Fedora

* Wed May 20 2020 joequant <joequant> 0-3.mga8
+ Revision: 1586290
- rebuild

* Tue May 19 2020 joequant <joequant> 0-2.mga8
+ Revision: 1586099
- redo to remove complex requires

* Mon May 18 2020 joequant <joequant> 0-1.mga8
+ Revision: 1586090
- imported package pyproject-rpm-macros

